
# Slot: object


class describing the activity, process or localization of the gene product

URI: [biolink:gene_to_go_term_association_object](https://w3id.org/biolink/vocab/gene_to_go_term_association_object)


## Domain and Range

[GeneToGoTermAssociation](GeneToGoTermAssociation.md) &#8594;  <sub>1..1</sub> [GeneOntologyClass](GeneOntologyClass.md)

## Parents

 *  is_a: [functional association➞object](functional_association_object.md)

## Children


## Used by

 * [GeneToGoTermAssociation](GeneToGoTermAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value='GO:0016301', description='kinase activity') |

